# SPDX-FileCopyrightText: 2020-2024 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ config, pkgs, ... }:

{
  programs = {
    adb.enable = pkgs.stdenv.isx86_64 && config.sbruder.full;
    bandwhich.enable = true;
    iotop.enable = true;
    wireshark = {
      enable = config.sbruder.gui.enable && config.sbruder.full;
      package = pkgs.wireshark;
    };
  };

  environment.systemPackages = with pkgs; [
    # top like tools
    bmon # network monitor
    mtr # interactive traceroute

    # batch processing/automation
    jq # sed for json

    # file tools
    compsize # btrfs compression statistics
    dos2unix # convert CRLF (dos) or CR (classic mac) line endings to LF (unix)
    file # file type
    ncdu # interactive du
    pipe-rename # interactive (in editor) renaming
    rename # sed for filenames
    ripgrep # better grep
    sqlite-interactive # cli for sqlite databases
    wget # download tool

    # encryption tools
    ssh-to-pgp # convert ssh host-key to pgp key

    # network tools
    dnsutils # dig
    iperf
    iperf2 # bandwidth measurement tool
    nmap # port scanner
    vnstat # client for vnstatd

    # system tools
    dmidecode # hardware information
    hdparm # hard drive management
    lm_sensors # temperature sensors
    parted # partition manager
    pciutils # lspci
    (reptyr.overrideAttrs (o: o // { doCheck = false; })) # move process to current terminal # tests fail on qemu-user-aarch64 (TODO 24.05: remove)
    smartmontools # hard drive monitoring
    tcpdump # package inspector
    tio # serial console
    usbutils # lsusb

    # eye candy
    ccze # log coloriser

    # helpers
    rlwrap # readline wrapper
  ];
}
